searchData={"items":[{"type":"module","title":"BambooHR","doc":"BambooHR API client library.\n\nA convenient way to interact with the BambooHR API from Elixir applications.","ref":"BambooHR.html"},{"type":"module","title":"API Resources - BambooHR","doc":"The library is organized into several modules, each representing a different\nAPI resource:\n\n- `BambooHR.Client` - Core client functionality and configuration\n- `BambooHR.Company` - Company information and EINs\n- `BambooHR.Employee` - Employee management\n- `BambooHR.TimeTracking` - Time entries and timesheets","ref":"BambooHR.html#module-api-resources"},{"type":"module","title":"Getting Started - BambooHR","doc":"Create a client configuration with your company subdomain and API key:\n\n    config = BambooHR.Client.new(\"your_company\", \"your_api_key\")\n\nThen use the resource modules to interact with the API:\n\n    # Get company information\n    {:ok, company_info} = BambooHR.Company.get_information(config)\n\n    # Get employee directory\n    {:ok, directory} = BambooHR.Employee.get_directory(config)\n\n    # Get specific employee details\n    {:ok, employee} = BambooHR.Employee.get(config, 123, [\"firstName\", \"lastName\", \"jobTitle\"])","ref":"BambooHR.html#module-getting-started"},{"type":"module","title":"BambooHR.Client","doc":"Client for interacting with the BambooHR API.","ref":"BambooHR.Client.html"},{"type":"module","title":"Configuration - BambooHR.Client","doc":"To use this client, you'll need information from BambooHR:\n- Your company's subdomain\n- An API key","ref":"BambooHR.Client.html#module-configuration"},{"type":"module","title":"Usage - BambooHR.Client","doc":"client = BambooHR.Client.new(\"your_company\", \"your_api_key\")\n    {:ok, company_info} = BambooHR.Company.get_information(client)","ref":"BambooHR.Client.html#module-usage"},{"type":"type","title":"BambooHR.Client.config/0","doc":"","ref":"BambooHR.Client.html#t:config/0"},{"type":"function","title":"BambooHR.Client.get/3","doc":"Makes a GET request to the BambooHR API.\n\nThis function is meant to be used by resource modules.","ref":"BambooHR.Client.html#get/3"},{"type":"function","title":"BambooHR.Client.new/3","doc":"Creates a new client configuration.","ref":"BambooHR.Client.html#new/3"},{"type":"function","title":"Parameters - BambooHR.Client.new/3","doc":"* `company_domain` - Your company's subdomain\n  * `api_key` - Your API key\n  * `base_url` - Optional custom base URL for the API (defaults to BambooHR's standard API URL)","ref":"BambooHR.Client.html#new/3-parameters"},{"type":"function","title":"Examples - BambooHR.Client.new/3","doc":"iex> client = BambooHR.Client.new(\"acme\", \"api_key_123\")\n    %{\n      company_domain: \"acme\",\n      api_key: \"api_key_123\",\n      base_url: \"https://api.bamboohr.com/api/gateway.php\"\n    }\n\n    # With custom base URL\n    iex> client = BambooHR.Client.new(\"acme\", \"api_key_123\", \"https://custom-api.example.com\")\n    %{\n      company_domain: \"acme\",\n      api_key: \"api_key_123\",\n      base_url: \"https://custom-api.example.com\"\n    }","ref":"BambooHR.Client.html#new/3-examples"},{"type":"function","title":"BambooHR.Client.post/3","doc":"Makes a POST request to the BambooHR API.\n\nThis function is meant to be used by resource modules.","ref":"BambooHR.Client.html#post/3"},{"type":"type","title":"BambooHR.Client.response/0","doc":"","ref":"BambooHR.Client.html#t:response/0"},{"type":"module","title":"BambooHR.Company","doc":"Functions for interacting with company information in the BambooHR API.","ref":"BambooHR.Company.html"},{"type":"function","title":"BambooHR.Company.get_eins/1","doc":"Retrieves company EINs (Employer Identification Numbers).\n\nReturns a list of EINs associated with the company.","ref":"BambooHR.Company.html#get_eins/1"},{"type":"function","title":"Parameters - BambooHR.Company.get_eins/1","doc":"* `client` - Client configuration created with `BambooHR.Client.new/3`","ref":"BambooHR.Company.html#get_eins/1-parameters"},{"type":"function","title":"Examples - BambooHR.Company.get_eins/1","doc":"iex> BambooHR.Company.get_eins(client)\n    {:ok, %{\n      \"eins\" => [\n        %{\"ein\" => \"12-3456789\", \"name\" => \"Acme Corp\"},\n        %{\"ein\" => \"98-7654321\", \"name\" => \"Acme Subsidiary\"}\n      ]\n    }}","ref":"BambooHR.Company.html#get_eins/1-examples"},{"type":"function","title":"BambooHR.Company.get_information/1","doc":"Retrieves company information.\n\nReturns basic company details including name, address, and employee count.","ref":"BambooHR.Company.html#get_information/1"},{"type":"function","title":"Parameters - BambooHR.Company.get_information/1","doc":"* `client` - Client configuration created with `BambooHR.Client.new/3`","ref":"BambooHR.Company.html#get_information/1-parameters"},{"type":"function","title":"Examples - BambooHR.Company.get_information/1","doc":"iex> BambooHR.Company.get_information(client)\n    {:ok, %{\n      \"name\" => \"Acme Corp\",\n      \"employeeCount\" => 100,\n      \"city\" => \"San Francisco\"\n    }}","ref":"BambooHR.Company.html#get_information/1-examples"},{"type":"module","title":"BambooHR.Employee","doc":"Functions for interacting with employee resources in the BambooHR API.","ref":"BambooHR.Employee.html"},{"type":"function","title":"BambooHR.Employee.add/2","doc":"Adds a new employee.","ref":"BambooHR.Employee.html#add/2"},{"type":"function","title":"Parameters - BambooHR.Employee.add/2","doc":"* `client` - Client configuration created with `BambooHR.Client.new/3`\n  * `employee_data` - Map containing the employee information (firstName and lastName are required)","ref":"BambooHR.Employee.html#add/2-parameters"},{"type":"function","title":"Examples - BambooHR.Employee.add/2","doc":"iex> employee_data = %{\"firstName\" => \"Jane\", \"lastName\" => \"Smith\"}\n    iex> BambooHR.Employee.add(client, employee_data)\n    {:ok, %{\"id\" => 124}}","ref":"BambooHR.Employee.html#add/2-examples"},{"type":"function","title":"BambooHR.Employee.get/3","doc":"Retrieves information about a specific employee.","ref":"BambooHR.Employee.html#get/3"},{"type":"function","title":"Parameters - BambooHR.Employee.get/3","doc":"* `client` - Client configuration created with `BambooHR.Client.new/3`\n  * `employee_id` - The ID of the employee to retrieve\n  * `fields` - List of field names to retrieve (e.g., [\"firstName\", \"lastName\", \"jobTitle\"])","ref":"BambooHR.Employee.html#get/3-parameters"},{"type":"function","title":"Examples - BambooHR.Employee.get/3","doc":"iex> BambooHR.Employee.get(client, 123, [\"firstName\", \"lastName\", \"jobTitle\"])\n    {:ok, %{\n      \"firstName\" => \"John\",\n      \"lastName\" => \"Doe\",\n      \"jobTitle\" => \"Software Engineer\"\n    }}","ref":"BambooHR.Employee.html#get/3-examples"},{"type":"function","title":"BambooHR.Employee.get_directory/1","doc":"Retrieves the company's employee directory.\n\nReturns a list of all employees with basic information like name and contact details.","ref":"BambooHR.Employee.html#get_directory/1"},{"type":"function","title":"Parameters - BambooHR.Employee.get_directory/1","doc":"* `client` - Client configuration created with `BambooHR.Client.new/3`","ref":"BambooHR.Employee.html#get_directory/1-parameters"},{"type":"function","title":"Examples - BambooHR.Employee.get_directory/1","doc":"iex> BambooHR.Employee.get_directory(client)\n    {:ok, %{\n      \"employees\" => [\n        %{\n          \"id\" => 123,\n          \"displayName\" => \"John Doe\",\n          \"jobTitle\" => \"Developer\",\n          \"workEmail\" => \"john@example.com\"\n        }\n      ]\n    }}","ref":"BambooHR.Employee.html#get_directory/1-examples"},{"type":"function","title":"BambooHR.Employee.update/3","doc":"Updates information for an existing employee.","ref":"BambooHR.Employee.html#update/3"},{"type":"function","title":"Parameters - BambooHR.Employee.update/3","doc":"* `client` - Client configuration created with `BambooHR.Client.new/3`\n  * `employee_id` - The ID of the employee to update\n  * `employee_data` - Map containing the updated employee information","ref":"BambooHR.Employee.html#update/3-parameters"},{"type":"function","title":"Examples - BambooHR.Employee.update/3","doc":"iex> update_data = %{\"firstName\" => \"Jane\", \"lastName\" => \"Smith-Jones\"}\n    iex> BambooHR.Employee.update(client, 124, update_data)\n    {:ok, %{}}","ref":"BambooHR.Employee.html#update/3-examples"},{"type":"module","title":"BambooHR.TimeTracking","doc":"Functions for interacting with time tracking resources in the BambooHR API.","ref":"BambooHR.TimeTracking.html"},{"type":"function","title":"BambooHR.TimeTracking.clock_in/3","doc":"Records a clock-in event for an employee.","ref":"BambooHR.TimeTracking.html#clock_in/3"},{"type":"function","title":"Parameters - BambooHR.TimeTracking.clock_in/3","doc":"* `client` - Client configuration created with `BambooHR.Client.new/3`\n  * `employee_id` - The ID of the employee to clock in\n  * `clock_data` - Map containing clock-in details (date, start time, timezone, etc.)","ref":"BambooHR.TimeTracking.html#clock_in/3-parameters"},{"type":"function","title":"Examples - BambooHR.TimeTracking.clock_in/3","doc":"iex> clock_data = %{\n    ...>   \"date\" => \"2024-01-15\",\n    ...>   \"start\" => \"09:00\",\n    ...>   \"timezone\" => \"America/New_York\"\n    ...> }\n    iex> BambooHR.TimeTracking.clock_in(client, 123, clock_data)\n    {:ok, %{\"message\" => \"Successfully clocked in\"}}","ref":"BambooHR.TimeTracking.html#clock_in/3-examples"},{"type":"function","title":"BambooHR.TimeTracking.clock_out/3","doc":"Records a clock-out event for an employee.","ref":"BambooHR.TimeTracking.html#clock_out/3"},{"type":"function","title":"Parameters - BambooHR.TimeTracking.clock_out/3","doc":"* `client` - Client configuration created with `BambooHR.Client.new/3`\n  * `employee_id` - The ID of the employee to clock out\n  * `clock_data` - Map containing clock-out details (date, end time, timezone)","ref":"BambooHR.TimeTracking.html#clock_out/3-parameters"},{"type":"function","title":"Examples - BambooHR.TimeTracking.clock_out/3","doc":"iex> clock_data = %{\n    ...>   \"date\" => \"2024-01-15\",\n    ...>   \"end\" => \"17:00\",\n    ...>   \"timezone\" => \"America/New_York\"\n    ...> }\n    iex> BambooHR.TimeTracking.clock_out(client, 123, clock_data)\n    {:ok, %{\"message\" => \"Successfully clocked out\"}}","ref":"BambooHR.TimeTracking.html#clock_out/3-examples"},{"type":"function","title":"BambooHR.TimeTracking.get_timesheet_entries/2","doc":"Retrieves timesheet entries within a specified date range.","ref":"BambooHR.TimeTracking.html#get_timesheet_entries/2"},{"type":"function","title":"Parameters - BambooHR.TimeTracking.get_timesheet_entries/2","doc":"* `client` - Client configuration created with `BambooHR.Client.new/3`\n  * `params` - Map containing query parameters (start, end dates, and optional employee IDs)","ref":"BambooHR.TimeTracking.html#get_timesheet_entries/2-parameters"},{"type":"function","title":"Examples - BambooHR.TimeTracking.get_timesheet_entries/2","doc":"iex> params = %{\n    ...>   \"start\" => \"2024-01-01\",\n    ...>   \"end\" => \"2024-01-31\",\n    ...>   \"employeeIds\" => \"123,124\"\n    ...> }\n    iex> BambooHR.TimeTracking.get_timesheet_entries(client, params)\n    {:ok, %{\n      \"entries\" => [\n        %{\n          \"id\" => \"1\",\n          \"employeeId\" => \"123\",\n          \"date\" => \"2024-01-15\",\n          \"hours\" => 8.0\n        }\n      ]\n    }}","ref":"BambooHR.TimeTracking.html#get_timesheet_entries/2-examples"},{"type":"function","title":"BambooHR.TimeTracking.store_clock_entries/2","doc":"Stores timesheet clock entries for employees.","ref":"BambooHR.TimeTracking.html#store_clock_entries/2"},{"type":"function","title":"Parameters - BambooHR.TimeTracking.store_clock_entries/2","doc":"* `client` - Client configuration created with `BambooHR.Client.new/3`\n  * `entries` - List of clock entry maps containing employee ID, date, start and end times","ref":"BambooHR.TimeTracking.html#store_clock_entries/2-parameters"},{"type":"function","title":"Examples - BambooHR.TimeTracking.store_clock_entries/2","doc":"iex> entries = [\n    ...>   %{\n    ...>     \"employeeId\" => \"123\",\n    ...>     \"date\" => \"2024-01-15\",\n    ...>     \"start\" => \"09:00:00\",\n    ...>     \"end\" => \"17:00:00\"\n    ...>   }\n    ...> ]\n    iex> BambooHR.TimeTracking.store_clock_entries(client, entries)\n    {:ok, %{\"message\" => \"Entries stored successfully\"}}","ref":"BambooHR.TimeTracking.html#store_clock_entries/2-examples"},{"type":"extras","title":"BambooHR","doc":"# BambooHR\n\n[![Hex Version](https://img.shields.io/hexpm/v/bamboo_hr.svg)](https://hex.pm/packages/bamboo_hr) [![Hex Docs](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/bamboo_hr/)\n\nAn Elixir client for the [Bamboo HR API][bamboohr-api-docs].","ref":"readme.html"},{"type":"extras","title":"Installation - BambooHR","doc":"The package can be installed by adding `bamboo_hr` to your\nlist of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:bamboo_hr, \"~> 0.2\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - BambooHR","doc":"To use this client, you'll need information from BambooHR:\n- Your company's subdomain\n- An API key","ref":"readme.html#usage"},{"type":"extras","title":"API Structure - BambooHR","doc":"The library is organized into several modules, each representing different API resources:\n\n- `BambooHR.Client` - Core client functionality and configuration\n- `BambooHR.Company` - Company information and EINs\n- `BambooHR.Employee` - Employee management\n- `BambooHR.TimeTracking` - Time entries and timesheets","ref":"readme.html#api-structure"},{"type":"extras","title":"Examples - BambooHR","doc":"#### Getting Started\n\nFirst, create a client configuration:\n\n```elixir\nconfig = BambooHR.Client.new(\"your_company\", \"your_api_key\")\n```\n\n#### Company Information\n\n```elixir\n# Get basic company information\n{:ok, company_info} = BambooHR.Company.get_information(config)\n\n# Get company EINs\n{:ok, eins_data} = BambooHR.Company.get_eins(config)\n```\n\n#### Employee Management\n\n```elixir\n# Get employee directory\n{:ok, directory} = BambooHR.Employee.get_directory(config)\n\n# Get specific employee details\n{:ok, employee} = BambooHR.Employee.get(config, 123, [\"firstName\", \"lastName\", \"jobTitle\"])\n\n# Add a new employee\nemployee_data = %{\"firstName\" => \"Jane\", \"lastName\" => \"Smith\"}\n{:ok, result} = BambooHR.Employee.add(config, employee_data)\n\n# Update an employee\nupdate_data = %{\"firstName\" => \"Jane\", \"lastName\" => \"Smith-Jones\"}\n{:ok, _} = BambooHR.Employee.update(config, 124, update_data)\n```\n\n#### Time Tracking\n\n```elixir\n# Get timesheet entries\nparams = %{\n  \"start\" => \"2024-01-01\",\n  \"end\" => \"2024-01-31\",\n  \"employeeIds\" => \"123,124\"\n}\n{:ok, timesheet_data} = BambooHR.TimeTracking.get_timesheet_entries(config, params)\n\n# Clock in an employee\nclock_data = %{\n  \"date\" => \"2024-01-15\",\n  \"start\" => \"09:00\",\n  \"timezone\" => \"America/New_York\"\n}\n{:ok, _} = BambooHR.TimeTracking.clock_in(config, 123, clock_data)\n\n# Clock out an employee\nclock_out_data = %{\n  \"date\" => \"2024-01-15\",\n  \"end\" => \"17:00\",\n  \"timezone\" => \"America/New_York\"\n}\n{:ok, _} = BambooHR.TimeTracking.clock_out(config, 123, clock_out_data)\n```","ref":"readme.html#examples"},{"type":"extras","title":"License - BambooHR","doc":"BambooHR is [released under the MIT license](LICENSE).\n\n[bamboohr-api-docs]: https://documentation.bamboohr.com/reference/","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file. See [Keep a\nCHANGELOG](http://keepachangelog.com/) for how to update this file. This project\nadheres to [Semantic Versioning](http://semver.org/).\n\n<!-- %% CHANGELOG_ENTRIES %% -->","ref":"changelog.html"},{"type":"extras","title":"0.2.0 - 2025-03-04 - Changelog","doc":"","ref":"changelog.html#0-2-0-2025-03-04"},{"type":"extras","title":"Changed - Changelog","doc":"- Introduced new modules for Company, Employee and TimeTracking resources\n- Improved the package documentation","ref":"changelog.html#changed"},{"type":"extras","title":"0.1.0 - 2025-01-29 - Changelog","doc":"Initial release. :rocket:","ref":"changelog.html#0-1-0-2025-01-29"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2025 Sasha Gerrand\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}